==> struts-6.8.0-src.zip: struts-6.8.0/src/apps/showcase/src/main/java/org/apache/struts2/showcase/LotsOfRichtexteditorAction.java <==
/*
 * $Id$
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.struts2.showcase;

import com.opensymphony.xwork2.ActionSupport;
import org.apache.struts2.interceptor.parameter.StrutsParameter;

/**
 *
 */
public class LotsOfRichtexteditorAction extends ActionSupport {

	public String description1;
	public String description2 = "This is Description 2";
	public String description3;
	public String description4 = "This is Description 4";

	public String getDescription1() {
		return this.description1;
	}

	@StrutsParameter
	public void setDescription1(String description1) {
		this.description1 = description1;
	}


	public String getDescription2() {
		return this.description2;
	}

	@StrutsParameter
	public void setDescription2(String description2) {
		this.description2 = description2;
	}


	public String getDescription3() {
		return this.description3;
	}

	@StrutsParameter
	public void setDescription3(String description3) {
		this.description3 = description3;
	}


	public String getDescription4() {
		return this.description4;
	}

	@StrutsParameter
	public void setDescription4(String description4) {
		this.description4 = description4;
	}

	@Override
	public String input() throws Exception {
		return SUCCESS;
	}

	public String submit() throws Exception {
		return SUCCESS;
	}
}

==> struts-7.0.3-src.zip: struts-7.0.3/src/apps/showcase/src/main/java/org/apache/struts2/showcase/LotsOfRichtexteditorAction.java <==
/*
 * $Id$
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.struts2.showcase;

import org.apache.struts2.ActionSupport;
import org.apache.struts2.interceptor.parameter.StrutsParameter;

/**
 *
 */
public class LotsOfRichtexteditorAction extends ActionSupport {

	public String description1;
	public String description2 = "This is Description 2";
	public String description3;
	public String description4 = "This is Description 4";

	public String getDescription1() {
		return this.description1;
	}

	@StrutsParameter
	public void setDescription1(String description1) {
		this.description1 = description1;
	}


	public String getDescription2() {
		return this.description2;
	}

	@StrutsParameter
	public void setDescription2(String description2) {
		this.description2 = description2;
	}


	public String getDescription3() {
		return this.description3;
	}

	@StrutsParameter
	public void setDescription3(String description3) {
		this.description3 = description3;
	}


	public String getDescription4() {
		return this.description4;
	}

	@StrutsParameter
	public void setDescription4(String description4) {
		this.description4 = description4;
	}

	@Override
	public String input() throws Exception {
		return SUCCESS;
	}

	public String submit() throws Exception {
		return SUCCESS;
	}
}
